(***********************************************************************)
(*                                                                     *)
(*                             Pio (OCaml)                             *)
(*                                                                     *)
(*                    Polyglot Input/Output Library                    *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2005-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: layout.mli,v 1.11 2014/02/09 20:13:38 fclement Exp $ *)

(** {3 Array layouts definition} *)

(** The definition of array layouts that are supported in the [Pio] library.
  The layout specifies how elements are stored in the lines/columns of arrays.
  A layout for a p-dimensional array is a permutation of the integer range
  [0..p-1] that specifies in which order the array should be filled.
  As a shortcut, we provide [C] and [F] for C or Fortran arrays layouts. *)

(** The type of layouts *)
type t =
   | Permutation of int Ulist1.t
   (** General layout of a p-dimensional array: a permutation of the integer range
     [0..p-1] where p is the dimension of the pD-array. *)
   | C | F
   (** C-like or Fortran-like layouts, respectively equivalent to the
     identity permutation and the reverse order permutation. *)
;;

val to_ob : Buffer.t -> t -> unit;;
val of_ib : Scanf.Scanning.scanbuf -> t;;
(** Reading/writing from/to I/O buffers. *)

val check : int -> t -> unit;;
(** [check p l] Checks the correctness of layout [l]:
  verifies that [l] a valid permutation of the range [0..p].
  Raises [Failure], if [l] is not a valid layout. *)
