(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: gen_test_identity_input.ml,v 1.3 2014-02-25 15:19:09 fclement Exp $ *)

module Nat = Unatural;;
module Cmd_opt = Ucommand_option;;

let pf = Pio.foreman_make_printing_facilities ();;

let piob = Uunix.std_process_io_buffers;;

let wrap tw = Pio.worker_test_wrap_task piob tw;;

let make_input make_wrapper fname =
  let { Pio.tname = tname; inj = inj; _; } = make_wrapper pf fname in
  wrap tname inj
;;

let make_init_input = make_input Wrapper.make_init_wrapper "init"
and make_grad_input = make_input Wrapper.make_grad_wrapper "grad"
and make_optim_input = make_input Wrapper.make_optim_wrapper "optim"
and make_final_input = make_input Wrapper.make_final_wrapper "final"
;;

let filename_flatten = Ulist.fold_left Filename.concat "";;

let bname = filename_flatten [ "."; "work"; "test_identity"; ];;

let make_main dim suff =
  Cmd_opt.parse ();
  
  let array_make x = Uarray.make dim x in
  let len = Nat._9_ in
  let matrix_make x = Umatrix.make dim len x in
  let matrix_init f = Umatrix.init dim len f in
  
  let constant_matrix = matrix_make in
  let two_zone_matrix j1 x0 x1 =
    matrix_init
      (fun _i j -> if j < j1 then x0 else x1) in
  
  make_init_input dim;
  
  let pm = constant_matrix 127. in
  make_grad_input pm;
  
  let ppm = two_zone_matrix 5 Nat._0_ Nat._1_
  and maa = array_make [| 0.; 0.; |] in
  make_optim_input (ppm, maa);
  
  let dname = Printf.sprintf "%s_%s" bname suff in
  let pm = two_zone_matrix 5 0. 127. in
  make_final_input (dname, pm);
;;
